/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "iomanip"
#include "../lib/potential.h"

using namespace gctl;

int main(int argc, char const *argv[]) try
{
    int spl_odr, smp_num;
    array<shc_data> SHCs;
    read_Swarm_shc("data/CHAOS8/CHAOS-8.2_core.shc", SHCs, spl_odr, smp_num);

    std::clog << SHCs.size() << std::endl;
    std::clog << std::setprecision(10) << SHCs.back().time << std::endl;
    std::cout << std::setprecision(10) << SHCs.back().coeff_s(20, 20) << std::endl;
    std::cout << std::setprecision(10) << SHCs.back().coeff_c(20, 20) << std::endl;

    save_Swarm_shc("tmp", SHCs, spl_odr, smp_num);
    return 0;
}
catch (std::exception &e)
{
    GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
}